@@ -3,6 +3,10 @@ import logging
 from datetime import datetime
 from functools import wraps
 
+from mlflow.entities import ViewType
+from mlflow.store.tracking.abstract_store import AbstractStore
+from mlflow.utils.rest_utils import MlflowHostCreds
+
 import dbnd
 
 from dbnd._core.task_build.task_context import try_get_current_task
@@ -10,9 +14,6 @@ from dbnd._core.tracking.registry import get_tracking_store
 from dbnd._core.tracking.schemas.metrics import Metric
 from dbnd._core.utils.basics.memoized import cached
 from dbnd._core.utils.timezone import utcnow
-from mlflow.entities import ViewType
-from mlflow.store.tracking.abstract_store import AbstractStore
-from mlflow.utils.rest_utils import MlflowHostCreds
 
 from .url_utils import parse_composite_uri
 
@@ -129,14 +130,14 @@ class DatabandStore(AbstractStore):
             # mlflow.entities.Metric.timestamp is `int(time.time() * 1000)`
             timestamp=datetime.fromtimestamp(metric.timestamp / 1000),
         )
-        self.dbnd_store.log_metric(self._get_current_task_run(), dbnd_metric)
+        self.dbnd_store.log_metrics(self._get_current_task_run(), [dbnd_metric])
         logger.info("Metric {}".format(metric))
 
     def _log_param(self, run_id, param):
         # type: (str, mlflow.entities.Param) -> None
         # Temporarly log params as metrics
         dbnd_metric = Metric(key=param.key, value=param.value, timestamp=utcnow())
-        self.dbnd_store.log_metric(self._get_current_task_run(), dbnd_metric)
+        self.dbnd_store.log_metrics(self._get_current_task_run(), [dbnd_metric])
         logger.info("Param {}".format(param))
 
     @duplication_store
@@ -179,6 +180,6 @@ def get_dbnd_store(store_uri=None, artifact_uri=None):
 
         duplication_store = _get_store(duplicate_tracking_to, artifact_uri)
 
-    dbnd_store = get_tracking_store(["api"], "web", True)
+    dbnd_store = get_tracking_store(["api"], "web", True, False)
 
     return DatabandStore(dbnd_store, duplication_store)
